package cn.hnthyy.thmz.service.his.mz;

import cn.hnthyy.thmz.entity.his.mz.CodeNameEntity;

import java.util.List;

public interface MzZdCommonService {
    /**
     * 查询国家字典
     * @return
     */
    List<CodeNameEntity> queryCountry();

    /**
     * 民族字典
     * @return
     */
    List<CodeNameEntity> queryNation();


    /**
     * 诊断字典
     * @return
     */
    List<CodeNameEntity> queryDiagnose();


    /**
     * 查询省份列表
     * @param
     * @return
     */
    List<CodeNameEntity> queryDistrict();


    /**
     * 查询关系列表
     * @param
     * @return
     */
    List<CodeNameEntity> queryRelation();


    /**
     * 查询所有的职业
     * @return
     */
    List<CodeNameEntity> queryOccupation();


    /**
     * 查询所有的入院状态
     * @return
     */
    List<CodeNameEntity> queryAdmissStatus();
}
